@@ -99,10 +99,10 @@ class SimpleConsumer:
                     self.scheduleInfoCache.update_schedule_info_cache()
                     getMessageResponse = self.messageClient.get_message(getMessageRequest)
                 else:
-                    self.logger.error("fetch message failed! ", str(traceback.format_exc()))
+                    self.logger.error("fetch message failed! " + str(traceback.format_exc()))
                     raise e
             else:
-                self.logger.error("fetch message failed! ", str(traceback.format_exc()))
+                self.logger.error("fetch message failed! " + str(traceback.format_exc()))
                 raise e
 
         # update scheduleInfocache when request have been transfered and talos auto location was set up
@@ -127,7 +127,7 @@ class SimpleConsumer:
             try:
                 assert start > 0
             except AssertionError as e:
-                self.logger.error("Exception in fetch_message: %", e)
+                self.logger.error("Exception in fetch_message: %s", e)
                 raise e
             end = len(messageAndOffsetList)
             return messageAndOffsetList[start:end]
