@@ -236,7 +236,7 @@ class TalosProducer(object):
                     userMessage = UserMessage(message)
                     partitionBufferMap.get(currentPartitionId).append(userMessage)
                 else:
-                    self.check_message_partition_key_validity(message.getPartitionKey())
+                    self.check_message_partition_key_validity(message.partitionKey)
                     # construct UserMessage and dispatch to buffer by partitionId
                     partitionId = self.get_partition_id(message.partitionKey)
                     if partitionId not in partitionBufferMap:
